@@ -33,9 +33,10 @@
 #  define KTEXTWIDGETS_DEPRECATED_NO_EXPORT KTEXTWIDGETS_NO_EXPORT KTEXTWIDGETS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KTEXTWIDGETS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KTEXTWIDGETS_NO_DEPRECATED
+#    define KTEXTWIDGETS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
